## Changelog

### [v0.1.3]
 - setup.py is now Python 3 compatible (but wlsqm itself is not yet!)
 - fixed sdist: package also CHANGELOG.md

### [v0.1.2]
 - set zip_safe to False to better work with Cython (important for libs that depend on this one)

### [v0.1.1]
 - change distribution system from distutils to setuptools

### [v0.1.0]
  - initial version

